Documentation
¶
Index ¶
Constants ¶
const (
// ComponentName just a name to identify this package/component/application
ComponentName = "sonataflow-manager"
)
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type SonataFlowBuildReconciler ¶
type SonataFlowBuildReconciler struct {
client.Client
Scheme *runtime.Scheme
Recorder record.EventRecorder
Config *rest.Config
}
SonataFlowBuildReconciler reconciles a SonataFlowBuild object
func (*SonataFlowBuildReconciler) Reconcile ¶
func (r *SonataFlowBuildReconciler) Reconcile(ctx context.Context, req ctrl.Request) (ctrl.Result, error)
Reconcile is part of the main kubernetes reconciliation loop which aims to move the current state of the cluster closer to the desired state. the SonataFlowBuild object against the actual cluster state, and then perform operations to make the cluster state reflect the state specified by the user.
For more details, check Reconcile and its Result here: - https://pkg.go.dev/sigs.k8s.io/controller-runtime@v0.12.1/pkg/reconcile
func (*SonataFlowBuildReconciler) SetupWithManager ¶
func (r *SonataFlowBuildReconciler) SetupWithManager(mgr ctrl.Manager) error
SetupWithManager sets up the controller with the Manager.
type SonataFlowClusterPlatformReconciler ¶
type SonataFlowClusterPlatformReconciler struct {
// This Client, initialized using mgr.Client() above, is a split Client
// that reads objects from the cache and writes to the API server
ctrl.Client
// Non-caching Client
Reader ctrl.Reader
Scheme *runtime.Scheme
Config *rest.Config
Recorder record.EventRecorder
}
SonataFlowClusterPlatformReconciler reconciles a SonataFlowClusterPlatform object
func (*SonataFlowClusterPlatformReconciler) Reconcile ¶
func (r *SonataFlowClusterPlatformReconciler) Reconcile(ctx context.Context, req reconcile.Request) (reconcile.Result, error)
Reconcile is part of the main kubernetes reconciliation loop which aims to move the current state of the cluster closer to the desired state. TODO(user): Modify the Reconcile function to compare the state specified by the SonataFlowClusterPlatform object against the actual cluster state, and then perform operations to make the cluster state reflect the state specified by the user.
For more details, check Reconcile and its Result here: - https://pkg.go.dev/sigs.k8s.io/controller-runtime@v0.13.0/pkg/reconcile
func (*SonataFlowClusterPlatformReconciler) SetupWithManager ¶
func (r *SonataFlowClusterPlatformReconciler) SetupWithManager(mgr ctrlrun.Manager) error
SetupWithManager sets up the controller with the Manager.
type SonataFlowPlatformReconciler ¶
type SonataFlowPlatformReconciler struct {
// This Client, initialized using mgr.Client() above, is a split Client
// that reads objects from the cache and writes to the API server
ctrl.Client
// Non-caching Client
Reader ctrl.Reader
Scheme *runtime.Scheme
Config *rest.Config
Recorder record.EventRecorder
}
SonataFlowPlatformReconciler reconciles a SonataFlowPlatform object
func (*SonataFlowPlatformReconciler) Reconcile ¶
func (r *SonataFlowPlatformReconciler) Reconcile(ctx context.Context, req reconcile.Request) (reconcile.Result, error)
Reconcile is part of the main kubernetes reconciliation loop which aims to move the current state of the cluster closer to the desired state. the SonataFlowPlatform object against the actual cluster state, and then perform operations to make the cluster state reflect the state specified by the user.
For more details, check Reconcile and its Result here: - https://pkg.go.dev/sigs.k8s.io/controller-runtime@v0.12.1/pkg/reconcile
func (*SonataFlowPlatformReconciler) SetupWithManager ¶
func (r *SonataFlowPlatformReconciler) SetupWithManager(mgr ctrlrun.Manager) error
SetupWithManager sets up the controller with the Manager.
type SonataFlowReconciler ¶
type SonataFlowReconciler struct {
Client client.Client
Scheme *runtime.Scheme
Config *rest.Config
Recorder record.EventRecorder
}
SonataFlowReconciler reconciles a SonataFlow object
func (*SonataFlowReconciler) Delete ¶
func (r *SonataFlowReconciler) Delete(e event.DeleteEvent) error
Delete implements a handler for the Delete event.
func (*SonataFlowReconciler) Reconcile ¶
func (r *SonataFlowReconciler) Reconcile(ctx context.Context, req ctrl.Request) (ctrl.Result, error)
Reconcile is part of the main kubernetes reconciliation loop which aims to move the current state of the cluster closer to the desired state. the SonataFlow object against the actual cluster state, and then perform operations to make the cluster state reflect the state specified by the user.
For more details, check Reconcile and its Result here: - https://pkg.go.dev/sigs.k8s.io/controller-runtime@v0.11.2/pkg/reconcile
func (*SonataFlowReconciler) SetupWithManager ¶
func (r *SonataFlowReconciler) SetupWithManager(mgr ctrl.Manager) error
SetupWithManager sets up the controller with the Manager.