cfg

package
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 23, 2026 License: Apache-2.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type ControllersCfg

type ControllersCfg struct {
	DefaultPvcKanikoSize            string            `yaml:"defaultPvcKanikoSize,omitempty"`
	HealthFailureThresholdDevMode   int32             `yaml:"healthFailureThresholdDevMode,omitempty"`
	KanikoDefaultWarmerImageTag     string            `yaml:"kanikoDefaultWarmerImageTag,omitempty"`
	KanikoExecutorImageTag          string            `yaml:"kanikoExecutorImageTag,omitempty"`
	JobsServicePostgreSQLImageTag   string            `yaml:"jobsServicePostgreSQLImageTag,omitempty"`
	JobsServiceEphemeralImageTag    string            `yaml:"jobsServiceEphemeralImageTag,omitempty"`
	DataIndexPostgreSQLImageTag     string            `yaml:"dataIndexPostgreSQLImageTag,omitempty"`
	DataIndexEphemeralImageTag      string            `yaml:"dataIndexEphemeralImageTag,omitempty"`
	DbMigratorToolImageTag          string            `yaml:"dbMigratorToolImageTag,omitempty"`
	SonataFlowBaseBuilderImageTag   string            `yaml:"sonataFlowBaseBuilderImageTag,omitempty"`
	SonataFlowDevModeImageTag       string            `yaml:"sonataFlowDevModeImageTag,omitempty"`
	BuilderConfigMapName            string            `yaml:"builderConfigMapName,omitempty"`
	PostgreSQLPersistenceExtensions []GroupArtifactId `yaml:"postgreSQLPersistenceExtensions,omitempty"`
	KogitoEventsGrouping            bool              `yaml:"kogitoEventsGrouping,omitempty"`
	KogitoEventsGroupingBinary      bool              `yaml:"KogitoEventsGroupingBinary,omitempty"`
	KogitoEventsGroupingCompress    bool              `yaml:"KogitoEventsGroupingCompress,omitempty"`
}

func GetCfg

func GetCfg() *ControllersCfg

func InitializeControllersCfg

func InitializeControllersCfg() (*ControllersCfg, error)

InitializeControllersCfg initializes the platform configuration for this instance. Must be called at the main initialization point.

For the main initialization, the configuration is discarded since the controllers will read the cache instance. We keep the pointer return here to make sure we can access it from tests if needed or implement an optional use the defaults if fail to read.

func InitializeControllersCfgAt

func InitializeControllersCfgAt(configFilePath string) (*ControllersCfg, error)

InitializeControllersCfgAt same as InitializeControllersCfg receiving a path as input.

type GroupArtifactId

type GroupArtifactId struct {
	GroupId    string `yaml:"groupId,omitempty"`
	ArtifactId string `yaml:"artifactId,omitempty"`
}

func (*GroupArtifactId) String

func (g *GroupArtifactId) String() string

Jump to