Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type WorkflowManager ¶
type WorkflowManager interface {
SetBuiltStatusToRunning(message string) error
GetWorkflow() *v1alpha08.SonataFlow
}
WorkflowManager offers a management interface for operations with SonataFlows instances outside the controller's package. Meant to be used by other packages that don't have access to a SonataFlow instance coming from a reconciliation cycle.
func NewManager ¶
Click to show internal directories.
Click to hide internal directories.