Documentation
¶
Index ¶
- Constants
- func Compare(a, b []byte) bool
- func Crc32Checksum(v interface{}) (int32, error)
- func GetClient() client.Client
- func GetDiscoveryClient(cfg *rest.Config) (discovery.DiscoveryInterface, error)
- func GetDynamicClient() *dynamic.DynamicClient
- func GetEnv(key, fallback string) string
- func GetOperatorIDAnnotation(obj metav1.Object) string
- func IsOpenShift() bool
- func OperatorID() string
- func Pbool(b bool) *bool
- func Pint(i int32) *int32
- func RemoveFileExtension(fileName string) string
- func RemoveKnownExtension(fileName, extension string) string
- func SendCloudEvent(event *cloudevents.Event, url string) error
- func SendCloudEventWithContext(event *cloudevents.Event, ctx context.Context, url string) error
- func SetClient(client client.Client)
- func SetDiscoveryClient(cli discovery.DiscoveryInterface)
- func SetDynamicClient(cli *dynamic.DynamicClient)
- func SetIsOpenShift(cfg *rest.Config)
- type ApplicationPropertiesBuilder
Constants ¶
const ( // DefaultServicePortName default service name to increase compatibility with Knative // // see: https://github.com/knative/specs/blob/main/specs/serving/runtime-contract.md#protocols-and-ports // By default we do support HTTP/2:https://quarkus.io/guides/http-reference#http2-support DefaultServicePortName = "h2c" LatestImageTag = "latest" )
Variables ¶
This section is empty.
Functions ¶
func Crc32Checksum ¶
func GetClient ¶
GetClient default client created by the main operator's thread. It's safe to use since it's set when the operator main function runs.
func GetDiscoveryClient ¶
func GetDiscoveryClient(cfg *rest.Config) (discovery.DiscoveryInterface, error)
func GetDynamicClient ¶
func GetDynamicClient() *dynamic.DynamicClient
GetDynamicClient default dynamic client created by the main operator's thread. It's safe to use since it's set when the operator main function runs.
func GetOperatorIDAnnotation ¶
GetOperatorIDAnnotation to safely get the operator id annotation value.
func IsOpenShift ¶
func IsOpenShift() bool
IsOpenShift is a global flag that can be safely called across reconciliation cycles, defined at the controller manager start.
func OperatorID ¶
func OperatorID() string
func RemoveFileExtension ¶
func RemoveKnownExtension ¶
func SendCloudEvent ¶
func SendCloudEvent(event *cloudevents.Event, url string) error
SendCloudEvent Sends a cloud event to the given url using the http protocol binding. By default, events are sent in binary mode.
func SendCloudEventWithContext ¶
SendCloudEventWithContext Sends a cloud event to the given url using the http protocol binding. By default, events are sent in binary mode.
func SetDiscoveryClient ¶
func SetDiscoveryClient(cli discovery.DiscoveryInterface)
func SetDynamicClient ¶
func SetDynamicClient(cli *dynamic.DynamicClient)
SetDynamicClient is meant for internal use only. Don't call it!
func SetIsOpenShift ¶
SetIsOpenShift sets the global flag isOpenShift by the controller manager. We don't need to keep fetching the API every reconciliation cycle that we need to know about the platform.
Types ¶
type ApplicationPropertiesBuilder ¶
type ApplicationPropertiesBuilder interface {
WithInitialProperties(initialProperties *properties.Properties) ApplicationPropertiesBuilder
WithImmutableProperties(immutableProperties *properties.Properties) ApplicationPropertiesBuilder
WithDefaultManagedProperties(defaultManagedProperties *properties.Properties) ApplicationPropertiesBuilder
BuildAsString() string
Build() *properties.Properties
}
func NewApplicationPropertiesBuilder ¶
func NewApplicationPropertiesBuilder() ApplicationPropertiesBuilder